==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/my_bookmarks.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_schedule'] = 						"schedule items";
$lang['hdr_library'] = 							"wiki pages";
$lang['hdr_my_bookmark'] = 						"removing marks and tips";
$lang['hdr_recommended'] = 						"tips";
$lang['hdr_subjects'] = 						"discussion subjects";
$lang['hdr_watching'] = 						"marks";
$lang['hdr_polls'] = 							"polls";


//SUBMIT BUTTONS
$lang['sub_delete'] = 							"delete";


//A HREF TAGS (links)
$lang['href_watching'] =						"marks &amp; tips";


//BODY TEXT
$lang['txt_delete_bookmark'] =					"To delete marks or tips check the box next to each item that you want to delete and then press the 'delete' button.";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";

?>

==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/my_bookmarks.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_schedule'] = 						"schedule items";
$lang['hdr_library'] = 							"wiki pages";
$lang['hdr_my_bookmark'] = 						"removing marks and tips";
$lang['hdr_recommended'] = 						"tips";
$lang['hdr_subjects'] = 						"discussion subjects";
$lang['hdr_watching'] = 						"marks";
$lang['hdr_polls'] = 							"polls";


//A HREF TAGS (links)
$lang['href_watching'] =						"marks &amp; tips";


//BODY TEXT
$lang['txt_delete_bookmark'] =					"To delete marks or tips check the box next to each item that you want to delete and then press the 'delete' button.";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";

?>
